package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcBudgetSiteMapper;
import com.ruoyi.oa.domain.CmcBudgetSite;
import com.ruoyi.oa.service.ICmcBudgetSiteService;

/**
 * cmc现场开支Service业务层处理
 * 
 * @author cmc
 * @date 2025-05-09
 */
@Service
public class CmcBudgetSiteServiceImpl implements ICmcBudgetSiteService 
{
    @Autowired
    private CmcBudgetSiteMapper cmcBudgetSiteMapper;

    /**
     * 查询cmc现场开支
     * 
     * @param expenseId cmc现场开支主键
     * @return cmc现场开支
     */
    @Override
    public CmcBudgetSite selectCmcBudgetSiteByExpenseId(Long expenseId)
    {
        return cmcBudgetSiteMapper.selectCmcBudgetSiteByExpenseId(expenseId);
    }

    /**
     * 查询cmc现场开支列表
     * 
     * @param cmcBudgetSite cmc现场开支
     * @return cmc现场开支
     */
    @Override
    public List<CmcBudgetSite> selectCmcBudgetSiteList(CmcBudgetSite cmcBudgetSite)
    {
        return cmcBudgetSiteMapper.selectCmcBudgetSiteList(cmcBudgetSite);
    }

    /**
     * 新增cmc现场开支
     * 
     * @param cmcBudgetSite cmc现场开支
     * @return 结果
     */
    @Override
    public int insertCmcBudgetSite(CmcBudgetSite cmcBudgetSite)
    {
        return cmcBudgetSiteMapper.insertCmcBudgetSite(cmcBudgetSite);
    }

    /**
     * 修改cmc现场开支
     * 
     * @param cmcBudgetSite cmc现场开支
     * @return 结果
     */
    @Override
    public int updateCmcBudgetSite(CmcBudgetSite cmcBudgetSite)
    {
        return cmcBudgetSiteMapper.updateCmcBudgetSite(cmcBudgetSite);
    }

    /**
     * 批量删除cmc现场开支
     * 
     * @param budgetIds 需要删除的cmc现场开支主键
     * @return 结果
     */
    @Override
    public int deleteCmcBudgetSiteByExpenseIds(String[] budgetIds)
    {
        return cmcBudgetSiteMapper.deleteCmcBudgetSiteByExpenseIds(budgetIds);
    }

    /**
     * 删除cmc现场开支信息
     * 
     * @param expenseId cmc现场开支主键
     * @return 结果
     */
    @Override
    public int deleteCmcBudgetSiteByExpenseId(Long expenseId)
    {
        return cmcBudgetSiteMapper.deleteCmcBudgetSiteByExpenseId(expenseId);
    }
}
